Improve this Doc View Source
Deprecated:

In an effort to keep synchronized with router changes in Angular 2, this implementation of the Component Router (ngComponentRouter module) has been deprecated and will not receive further updates. We are investigating backporting the Angular 2 Router to Angular 1, but alternatively, use the `ngRoute` module or community developed projects (e.g. ui-router).

A `Router` is responsible for mapping URLs to components.

- Routers and "Routing Component" instances have a 1:1 correspondence.
- The Router holds reference to one or more of Outlets.
- There are two kinds of Router: `RootRouter` and `ChildRouter`.

You can see the state of a router by inspecting the read-only field `router.navigating`. This may be useful for showing a spinner, for instance.